# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openapi_client.models.patched_income import PatchedIncome  # noqa: E501

class TestPatchedIncome(unittest.TestCase):
    """PatchedIncome unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedIncome:
        """Test PatchedIncome
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedIncome`
        """
        model = PatchedIncome()  # noqa: E501
        if include_optional:
            return PatchedIncome(
                id = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_deleted = True,
                amount = '-80728880',
                comment = '',
                category = 56,
                created_by = 56,
                wallet = 56,
                group = 56
            )
        else:
            return PatchedIncome(
        )
        """

    def testPatchedIncome(self):
        """Test PatchedIncome"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
