# coding: utf-8

# flake8: noqa
"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.api_user import APIUser
from openapi_client.models.currency import Currency
from openapi_client.models.currency_rate import CurrencyRate
from openapi_client.models.expense import Expense
from openapi_client.models.expense_category import ExpenseCategory
from openapi_client.models.group import Group
from openapi_client.models.income import Income
from openapi_client.models.income_category import IncomeCategory
from openapi_client.models.invite import Invite
from openapi_client.models.paginated_api_user_list import PaginatedAPIUserList
from openapi_client.models.paginated_currency_list import PaginatedCurrencyList
from openapi_client.models.paginated_currency_rate_list import PaginatedCurrencyRateList
from openapi_client.models.paginated_expense_category_list import PaginatedExpenseCategoryList
from openapi_client.models.paginated_expense_list import PaginatedExpenseList
from openapi_client.models.paginated_group_list import PaginatedGroupList
from openapi_client.models.paginated_income_category_list import PaginatedIncomeCategoryList
from openapi_client.models.paginated_income_list import PaginatedIncomeList
from openapi_client.models.paginated_transfer_list import PaginatedTransferList
from openapi_client.models.paginated_wallet_list import PaginatedWalletList
from openapi_client.models.patched_api_user import PatchedAPIUser
from openapi_client.models.patched_currency import PatchedCurrency
from openapi_client.models.patched_currency_rate import PatchedCurrencyRate
from openapi_client.models.patched_expense import PatchedExpense
from openapi_client.models.patched_expense_category import PatchedExpenseCategory
from openapi_client.models.patched_group import PatchedGroup
from openapi_client.models.patched_income import PatchedIncome
from openapi_client.models.patched_income_category import PatchedIncomeCategory
from openapi_client.models.patched_transfer import PatchedTransfer
from openapi_client.models.patched_wallet import PatchedWallet
from openapi_client.models.report import Report
from openapi_client.models.signup import Signup
from openapi_client.models.transfer import Transfer
from openapi_client.models.wallet import Wallet
