# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.reports_api import ReportsApi  # noqa: E501


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_report_html_retrieve(self) -> None:
        """Test case for report_html_retrieve

        """
        pass

    def test_report_list(self) -> None:
        """Test case for report_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
