# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openapi_client.models.report import Report  # noqa: E501

class TestReport(unittest.TestCase):
    """Report unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Report:
        """Test Report
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Report`
        """
        model = Report()  # noqa: E501
        if include_optional:
            return Report(
                balance = 1.337,
                total_incomes = 1.337,
                total_expenses = 1.337,
                income_expense_ratio = 1.337,
                category_incomes = {
                    'key' : null
                    },
                category_expenses = {
                    'key' : null
                    }
            )
        else:
            return Report(
                balance = 1.337,
                total_incomes = 1.337,
                total_expenses = 1.337,
                income_expense_ratio = 1.337,
                category_incomes = {
                    'key' : null
                    },
                category_expenses = {
                    'key' : null
                    },
        )
        """

    def testReport(self):
        """Test Report"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
