# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openapi_client.models.paginated_api_user_list import PaginatedAPIUserList  # noqa: E501

class TestPaginatedAPIUserList(unittest.TestCase):
    """PaginatedAPIUserList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedAPIUserList:
        """Test PaginatedAPIUserList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedAPIUserList`
        """
        model = PaginatedAPIUserList()  # noqa: E501
        if include_optional:
            return PaginatedAPIUserList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    openapi_client.models.api_user.APIUser(
                        token = 'YQ==', )
                    ]
            )
        else:
            return PaginatedAPIUserList(
        )
        """

    def testPaginatedAPIUserList(self):
        """Test PaginatedAPIUserList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
