# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.currency_api import CurrencyApi  # noqa: E501


class TestCurrencyApi(unittest.TestCase):
    """CurrencyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CurrencyApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_currency_create(self) -> None:
        """Test case for currency_create

        """
        pass

    def test_currency_destroy(self) -> None:
        """Test case for currency_destroy

        """
        pass

    def test_currency_list(self) -> None:
        """Test case for currency_list

        """
        pass

    def test_currency_partial_update(self) -> None:
        """Test case for currency_partial_update

        """
        pass

    def test_currency_retrieve(self) -> None:
        """Test case for currency_retrieve

        """
        pass

    def test_currency_update(self) -> None:
        """Test case for currency_update

        """
        pass

    def test_currencyrate_create(self) -> None:
        """Test case for currencyrate_create

        """
        pass

    def test_currencyrate_destroy(self) -> None:
        """Test case for currencyrate_destroy

        """
        pass

    def test_currencyrate_get_rate_retrieve(self) -> None:
        """Test case for currencyrate_get_rate_retrieve

        """
        pass

    def test_currencyrate_list(self) -> None:
        """Test case for currencyrate_list

        """
        pass

    def test_currencyrate_partial_update(self) -> None:
        """Test case for currencyrate_partial_update

        """
        pass

    def test_currencyrate_retrieve(self) -> None:
        """Test case for currencyrate_retrieve

        """
        pass

    def test_currencyrate_update(self) -> None:
        """Test case for currencyrate_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
