# coding: utf-8

"""
    MoneyBox

    MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.invites_api import InvitesApi  # noqa: E501


class TestInvitesApi(unittest.TestCase):
    """InvitesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InvitesApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_invite_create(self) -> None:
        """Test case for invite_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
